/**
 * @license
 * Copyright 2022 Dynatrace LLC
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/// <reference types="node" />
/// <reference types="node" />
import { SourceMapConsumer } from 'source-map';
interface PrepareStackTraceContext {
    func: (err: Error, stackTraces: NodeJS.CallSite[]) => string | undefined;
    consumer: SourceMapConsumer;
}
/**
 * Generates a function that can be registered with `Error.prepareStackTrace`
 * (see https://v8.dev/docs/stack-trace-api#customizing-stack-traces).
 * A source map consumer is also returned because it must be destroyed manually after
 * code execution to free memory.
 */
export declare function createPrepareStackTrace(scriptName: string, sourceMap: Buffer): Promise<PrepareStackTraceContext>;
/** Applies sourcemaps to a stack trace. */
export declare function applySourcemapsToStackTrace(scriptName: string, stackTrace: string, consumer: SourceMapConsumer): string;
export {};
