/**
 * @license
 * Copyright 2022 Dynatrace LLC
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
interface ErrorEventInit extends EventInit {
    colno?: number;
    error?: any;
    filename?: string;
    lineno?: number;
    message?: string;
}
export declare class ErrorEvent extends Event {
    readonly colno: number;
    readonly error: any;
    readonly filename: string;
    readonly lineno: number;
    readonly message: string;
    /** */
    constructor(type: 'error', eventInitDict?: ErrorEventInit);
}
interface PromiseRejectionEventInit extends EventInit {
    promise?: Promise<unknown>;
    reason?: any;
}
export declare class PromiseRejectionEvent extends Event {
    readonly promise?: Promise<unknown>;
    readonly reason?: any;
    /** PromiseRejectionEvent constructor */
    constructor(type: 'unhandledrejection', eventInitDict?: PromiseRejectionEventInit);
}
interface CustomEventInit extends EventInit {
    readonly details?: any;
}
export declare class CustomEvent extends Event {
    details: any;
    /** */
    constructor(type: string, options?: CustomEventInit);
}
interface ProgressEventInit extends EventInit {
    lengthComputable?: boolean;
    loaded?: number;
    total?: number;
}
export declare class ProgressEvent<T extends EventTarget = EventTarget> extends Event {
    readonly lengthComputable: boolean;
    readonly loaded: number;
    readonly total: number;
    readonly target: T | null;
    /** */
    constructor(type: string, init?: ProgressEventInit);
}
export {};
